@@ -2,6 +2,7 @@ package Alien::Base;
 
 use strict;
 use warnings;
+use 5.008004;
 use Carp;
 use Path::Tiny ();
 use Scalar::Util qw/blessed/;
@@ -9,7 +10,7 @@ use Capture::Tiny 0.17 qw/capture_stdout/;
 use Text::ParseWords qw/shellwords/;
 
 # ABSTRACT: Base classes for Alien:: modules
-our $VERSION = '2.23'; # VERSION
+our $VERSION = '2.41'; # VERSION
 
 
 sub import {
@@ -505,6 +506,7 @@ sub inline_auto_include {
 
 sub Inline {
   my ($class, $language) = @_;
+  return unless defined $language;
   return if $language !~ /^(C|CPP)$/;
   my $config = {
     # INC should arguably be for -I flags only, but
@@ -624,7 +626,7 @@ Alien::Base - Base classes for Alien:: modules
 
 =head1 VERSION
 
-version 2.23
+version 2.41
 
 =head1 SYNOPSIS
 
@@ -678,7 +680,7 @@ Or if you are using L<ExtUtils::Depends>:
    $eud->get_makefile_vars
  );
 
-If you are using L<Alien:Base::ModuleBuild> instead of the recommended L<Alien::Build>
+If you are using L<Alien::Base::ModuleBuild> instead of the recommended L<Alien::Build>
 and L<alienfile>, then in your C<MyLibrary::XS> module, you may need something like
 this in your main C<.pm> file IF your library uses dynamic libraries:
 
@@ -1019,7 +1021,7 @@ Then in your base class:
 
  package Alien::MyLibrary;
  
- use base qw( Alien::Base );
+ use parent qw( Alien::Base );
  use Role::Tiny::With qw( with );
  
  with 'Alien::Role::Alt';
@@ -1057,7 +1059,7 @@ If you find a bug, please report it on the projects issue tracker on GitHub:
 
 =over 4
 
-=item L<https://github.com/Perl5-Alien/Alien-Base/issues>
+=item L<https://github.com/PerlAlien/Alien-Base/issues>
 
 =back
 
@@ -1076,7 +1078,7 @@ request.
 
 =over 4
 
-=item L<https://github.com/Perl5-Alien/Alien-Base/pulls>
+=item L<https://github.com/PerlAlien/Alien-Base/pulls>
 
 =back
 
@@ -1188,6 +1190,10 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
