@@ -3,19 +3,23 @@ package Alien::Build::Plugin;
 use strict;
 use warnings;
 use 5.008004;
+use Data::Dumper ();
 use Carp ();
+use Digest::SHA ();
 
 our @CARP_NOT = qw( alienfile Alien::Build Alien::Build::Meta );
 
 # ABSTRACT: Plugin base class for Alien::Build
-our $VERSION = '2.29'; # VERSION
+our $VERSION = '2.41'; # VERSION
 
 
 sub new
 {
   my $class = shift;
   my %args = @_ == 1 ? ($class->meta->default => $_[0]) : @_;
-  my $self = bless {}, $class;
+
+  my $instance_id = Digest::SHA::sha1_hex(Data::Dumper->new([$class, \%args])->Sortkeys(1)->Dump);
+  my $self = bless { instance_id => $instance_id }, $class;
 
   my $prop = $self->meta->prop;
   foreach my $name (keys %$prop)
@@ -36,6 +40,9 @@ sub new
 }
 
 
+sub instance_id { shift->{instance_id} }
+
+
 sub init
 {
   my($self) = @_;
@@ -139,7 +146,7 @@ Alien::Build::Plugin - Plugin base class for Alien::Build
 
 =head1 VERSION
 
-version 2.29
+version 2.41
 
 =head1 SYNOPSIS
 
@@ -224,6 +231,17 @@ Look for packages already installed on the system.
 
  my $plugin = Alien::Build::Plugin->new(%props);
 
+=head2 PROPERTIES
+
+=head2 instance_id
+
+ my $id = $plugin->instance_id;
+
+Returns an instance id for the plugin.  This is computed from the class and
+arguments that are passed into the plugin constructor, so technically two
+instances with the exact same arguments will have the same instance id, but
+in practice you should never have two instances with the exact same arguments.
+
 =head1 METHODS
 
 =head2 init
@@ -336,6 +354,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
