@@ -5,7 +5,7 @@ use warnings;
 use 5.008004;
 
 # ABSTRACT: Extend Alien::Base with roles!
-our $VERSION = '2.38'; # VERSION
+our $VERSION = '2.41'; # VERSION
 
 
 1;
@@ -22,13 +22,13 @@ Alien::Role - Extend Alien::Base with roles!
 
 =head1 VERSION
 
-version 2.38
+version 2.41
 
 =head1 SYNOPSIS
 
  package Alien::libfoo;
  
- use base qw( Alien::Base );
+ use parent qw( Alien::Base );
  use Role::Tiny::With qw( with );
  
  with 'Alien::Role::Dino';
@@ -128,6 +128,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
